%define anolis_release 2
%bcond_with tests

Summary: Tool for managing bootable, immutable filesystem trees
Name: ostree
Version: 2023.1
Release: %{anolis_release}%{?dist}
Source0: https://github.com/ostreedev/%{name}/releases/download/v%{version}/libostree-%{version}.tar.xz
License: LGPLv2+
URL: https://ostree.readthedocs.io/en/latest/

BuildRequires: make
BuildRequires: gtk-doc
BuildRequires: pkgconfig(avahi-client) >= 0.6.31
BuildRequires: pkgconfig(avahi-glib) >= 0.6.31
BuildRequires: pkgconfig(bash-completion)
BuildRequires: pkgconfig(e2p)
BuildRequires: pkgconfig(fuse3) >= 3.1.1
BuildRequires: pkgconfig(gio-unix-2.0) >= 2.66.0
BuildRequires: pkgconfig(gpg-error)
BuildRequires: pkgconfig(gpgme) >= 1.8.0
BuildRequires: pkgconfig(libarchive) >= 2.8.0
BuildRequires: pkgconfig(libcrypto) >= 1.0.1
BuildRequires: pkgconfig(libcurl) >= 7.29.0
BuildRequires: pkgconfig(liblzma) >= 5.0.5
BuildRequires: pkgconfig(libselinux) >= 2.1.13
BuildRequires: pkgconfig(libsoup-2.4) >= 2.39.1
BuildRequires: pkgconfig(libsystemd)
BuildRequires: pkgconfig(mount) >= 2.23.0
BuildRequires: pkgconfig(zlib)
BuildRequires: /usr/bin/g-ir-scanner
BuildRequires: dracut
BuildRequires: bison

# Runtime requirements
Requires: dracut
Requires: /usr/bin/gpgv2
Requires: systemd-units
Requires: %{name}-libs = %{version}-%{release}

%description
libostree is a shared library designed primarily for
use by higher level tools to manage host systems (e.g. rpm-ostree),
as well as container tools like flatpak and the atomic CLI.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%package libs
Summary: Development headers for %{name}

%description libs
The %{name}-libs provides shared libraries for %{name}.

%package devel
Summary: Development headers for %{name}
Requires: %{name}-libs = %{version}-%{release}

%description devel
The %{name}-devel package includes the header files for the %{name} library.

%package grub2
Summary: GRUB2 integration for OSTree
%ifnarch aarch64 loongarch64
Requires: grub2
%else
Requires: grub2-efi
%endif
Requires: ostree = %{version}-%{release}

%description grub2
GRUB2 integration for OSTree

%if %{with tests}
%package tests
Summary: Tests for the %{name} package
Requires: %{name} = %{version}-%{release}
Requires: %{name}-libs = %{version}-%{release}

%description tests
This package contains tests that can be used to verify
the functionality of the installed %{name} package.
%endif

%prep
%autosetup -n libostree-%{version}

%build
%configure --disable-silent-rules \
           --enable-gtk-doc \
           --with-selinux \
           --with-curl \
           --with-openssl \
           %{?with_tests:--enable-installed-tests=exclusive} \
           --with-dracut=yesbutnoconf
%make_build

%install
%make_install

%generate_compatibility_deps

%if !%{with tests}
rm -f %{buildroot}%{_libexecdir}/libostree/ostree-trivial-httpd
%endif

# Needed to enable the service at compose time currently
%post
%systemd_post ostree-remount.service

%preun
%systemd_preun ostree-remount.service

%files
%license COPYING
%{_bindir}/ostree
%{_bindir}/rofiles-fuse
%{abidir}/ostree-option.list
%{abidir}/rofiles-fuse-option.list
%{_datadir}/ostree
%{_datadir}/bash-completion/completions/*
%{_prefix}/lib/dracut/modules.d/98ostree
%{_prefix}/lib/systemd/system/ostree*.*
%{_prefix}/lib/systemd/system-generators/ostree-system-generator
%{_mandir}/man*/*
%dir %{_libexecdir}/libostree
%{_prefix}/lib/tmpfiles.d/*
%{_prefix}/lib/ostree

%files doc
%doc README.md

%files libs
%dir %{abidir}
%{_sysconfdir}/ostree
%{_libdir}/*.so.1*
%{abidir}/*.dump
%{_libdir}/girepository-1.0/OSTree-1.0.typelib

%files devel
%{_libdir}/lib*.so
%{_includedir}/*
%{_libdir}/pkgconfig/*
%{_datadir}/gtk-doc/html/ostree
%{_datadir}/gir-1.0/OSTree-1.0.gir

%files grub2
%{_sysconfdir}/grub.d/*ostree
%{_libexecdir}/libostree/grub2*

%if %{with tests}
%files tests
%{_libexecdir}/installed-tests
%{_datadir}/installed-tests
%{_libexecdir}/libostree/ostree-trivial-httpd
%endif

%changelog
* Wed Jan  3 2024 Wenlong Zhang <zhangwenlong@loongson.cn> - 2023.1-2
- fix install error for loongarch64

* Mon Feb 20 2023 Funda Wang <fundawang@yeah.net> - 2023.1-1
- New version 2023.1

* Sun Nov 20 2022 Funda Wang <fundawang@yeah.net> - 2022.6-1
- New version 2022.6

* Wed Nov 02 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 2022.1-3
- optimise spec file

* Wed Mar 23 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 2022.1-2
- change to use fuse3

* Wed Mar 09 2022 Yuanhong Peng <yummypeng@linux.alibaba.com> - 2022.1-1
- Init from upstream v2022.1
